#!/bin/bash
# input - which revision to compare 
#	positive: number of hours ago, can be fractional
#       negative: number of commits back ago
#       default is 24 hours ago

ARG1=${1:-24}

MAIN=main-final # name of the main file
PTH=../AISTATS2020 # path to the main file
TMP=../temp # path for a temp to reconstruct the previous revision

if [[ $ARG1 -gt 0 ]]; then
	echo "comparing to the version $ARG1 hours ago"
else
	echo "comparing to the version $(( 0 - $ARG1)) commits ago"
fi

mkdir -p ${TMP}
cpwd=$(pwd)

rsync -a ${PTH}/* ${TMP} #--exclude ../temp

rm -rf ${TMP}/${MAIN}.pfd

find . -name '*.tex' -o -name '*.bib' | while read F; do
    d=$(dirname "$F")
    if [[ $ARG1 -gt 0 ]]; then
	git show HEAD@{$ARG1.hours.ago}:$F > ${TMP}/${F:2}.old #
    else
	git show HEAD~$((0 - $ARG1)):$F > ${TMP}/${F:2}.old #	
    fi
    if [[ $d =~ .*style ]]; then  # do not decorate "style" files
	echo skipping ${F}
	continue
    fi
    if [ "${F##*.}" = "tex" ];then
	echo diff ${F}
	./latexdiff --preamble=${PTH}/style/diff_preamble.tex --ignore-warnings --subtype=SAFE --math-markup=1 ${TMP}/${F:2}.old $F > ${TMP}/${F:2}
#	./latexdiff --preamble=${PTH}/style/diff_preamble.tex --ignore-warnings ${TMP}/${F:2}.old $F > ${TMP}/${F:2}
    fi
done
cd ${TMP}
pdflatex -synctex=-1 -interaction=nonstopmode -shell-escape ${MAIN}.tex > pdflatex.log
pdflatex -synctex=-1 -interaction=nonstopmode -shell-escape ${MAIN}.tex > pdflatex.log
cp ${MAIN}.pdf ${cpwd}/${MAIN}-diff.pdf
#cp main.synctex ../latex/diff.synctex
#cp ../latex/main.pdf ../latex/diff.pdf
cp ${cpwd}/${MAIN}.synctex ${cpwd}/${MAIN}-diff.synctex
#bibtex diff
#pdflatex diff.tex
cd $cpwd

echo "Done."

exit 0